@@ -6,20 +6,25 @@ from datetime import datetime
 from time import time
 
 #URL = 'http://www.tfl.gov.uk/tfl/livetravelnews/realtime/by-date.aspx?offset=weekend'
-URL = 'http://www.tfl.gov.uk/tfl/livetravelnews/realtime/tube/default.html'
+TUBE_URL = 'http://www.tfl.gov.uk/tfl/livetravelnews/realtime/tube/default.html'
+#DLR_URL = 'http://www.tfl.gov.uk/tfl/livetravelnews/realtime/dlr/dlr-all-weekend.html'
+DLR_URL = 'http://www.tfl.gov.uk/tfl/livetravelnews/realtime/dlr/default.html'
 
 OUTFILE = 'Closures.txt'
 
-GOOD_SERVICE = ['Good service']
-PART_CLOSURE = ['Part closure', 'Part suspended']
-DELAYS = ['Severe delays']
-PLANNED_CLOSURE = ['Planned closure']
-LINE_ID = '<dt class="'
-STATION_ID = '<h3>'
-STATION_END_ID = '<dt>Station maintenance</dt>'
+TUBE_GOOD_SERVICE = ['Good service']
+TUBE_PART_CLOSURE = ['Part closure', 'Part suspended']
+TUBE_DELAYS = ['Severe delays']
+TUBE_PLANNED_CLOSURE = ['Planned closure']
+TUBE_LINE_ID = '<dt class="'
+TUBE_STATION_ID = '<h3>'
+TUBE_STATION_END_ID = '<dt>Station maintenance</dt>'
 TUBE_LINES = 'Tube lines'
 TUBE_STATIONS = 'Closed stations'
 
+DLR_NAME = 'DLR'
+DLR_MESSAGE_ID = '<div class="message">'
+
 LINES = ['Bakerloo', 'Central', 'Circle', 'District', 'Hammersmith & City', 'Jubilee', 'Metropolitan', 'Northern', 'Piccadilly', 'Victoria', 'Waterloo & City']
 
 LINE_REPLACEMENTS = [['H\'smith', 'Hammersmith']]
@@ -105,43 +110,46 @@ def get(fname=OUTFILE):
 	if (bOld or outdated(fname)):
 		try:
 			print "Fetching data from TfL website..."
-			f = urllib.urlopen(URL, None)
-			lines = f.readlines()
+			f = urllib.urlopen(TUBE_URL, None)
+			tube_lines = f.readlines()
+			f.close()
+			f = urllib.urlopen(DLR_URL, None)
+			dlr_lines = f.readlines()
 			f.close()
 			print "Parsing data..."
-			for i in range(len(lines)):
-				s = get_info(lines[i])
+			for i in range(len(tube_lines)):
+				s = get_info(tube_lines[i])
 				if s != "":
 					if s == TUBE_LINES:
 						mode = "T"
-						print "  (1/2) Tube lines."
+						print "  (1/3) Tube lines."
 					elif s == TUBE_STATIONS:
 						mode = "S"
-						print "  (2/2) Tube stations."
+						print "  (2/3) Tube stations."
 					else:
 						if mode == "T":
-							line = lines[i].strip()
+							line = tube_lines[i].strip()
 							if line != "":
-								if line[0:len(LINE_ID)] == LINE_ID:
+								if line[0:len(TUBE_LINE_ID)] == TUBE_LINE_ID:
 									affected = get_info(line)
 								else:
-									if s in PART_CLOSURE:
+									if s in TUBE_PART_CLOSURE:
 										i += 2
-										part_closures += ';'.join(parse_affected(affected, parse_routeinfo(lines[i]))) + ';'
-									if s in PLANNED_CLOSURE:
+										part_closures += ';'.join(parse_affected(affected, parse_routeinfo(tube_lines[i]))) + ';'
+									if s in TUBE_PLANNED_CLOSURE:
 										planned_closures += affected + ';'
-									if s in DELAYS:
+									if s in TUBE_DELAYS:
 										delays += affected + ';'
 						elif mode == "S":
-							line = lines[i].strip()
-							if line == STATION_END_ID:
+							line = tube_lines[i].strip()
+							if line == TUBE_STATION_END_ID:
 								mode = ""
 							if line != "":
-								if line[0:len(STATION_ID)] == STATION_ID:
+								if line[0:len(TUBE_STATION_ID)] == TUBE_STATION_ID:
 									for repl in STATION_REPLACEMENTS:
 										affected = get_info(line).replace(repl[0], repl[1]).strip()
 									i += 2
-									line = lines[i]
+									line = tube_lines[i]
 									interchange = False
 									for tube_line in LINES:
 										if line.find(tube_line) != -1:
@@ -149,6 +157,15 @@ def get(fname=OUTFILE):
 											interchange_closures += "%s,%s,*;" % (affected, tube_line)
 									if not interchange:
 										station_closures += affected + ";"
+			print "  (3/3) DLR."
+			for i in range(len(dlr_lines)):
+				if dlr_lines[i][0:len(DLR_MESSAGE_ID)] == DLR_MESSAGE_ID:
+					if s.find('suspended') > -1:
+						s = get_info(dlr_lines[i+1]).strip()
+						affected = ';'.join(parse_affected(DLR_NAME, parse_routeinfo(s)))
+						if part_closures != "":
+							part_closures = ';' + part_closures
+						part_closures += affected
 		except IOError:
 			bOld = False
 			print "Could not fetch data."
